@@ -95,7 +95,7 @@ enum {
 
 static guint signals[N_SIGNALS] = { 0 };
 
-G_DEFINE_TYPE (GnomeBG, gnome_bg, G_TYPE_OBJECT);
+G_DEFINE_TYPE (GnomeBG, gnome_bg, G_TYPE_OBJECT)
 
 static GdkPixmap *make_root_pixmap     (GdkScreen  *screen,
 					gint        width,
@@ -828,6 +828,9 @@ get_current_slide (SlideShow *show,
 	double elapsed;
 	int i;
 
+	if (delta < 0)
+		delta += show->total_duration;
+
 	elapsed = 0;
 	i = 0;
 	for (list = show->slides->head; list != NULL; list = list->next) {
